Class: Gbizinfo::CertificationInfo

Inherits:
ApiModelBase show all
Defined in:
lib/gbizinfo/models/certification_info.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CertificationInfo

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/gbizinfo/models/certification_info.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Gbizinfo::CertificationInfo` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Gbizinfo::CertificationInfo`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  end

  if attributes.key?(:'date_of_approval')
    self.date_of_approval = attributes[:'date_of_approval']
  end

  if attributes.key?(:'enterprise_scale')
    self.enterprise_scale = attributes[:'enterprise_scale']
  end

  if attributes.key?(:'expiration_date')
    self.expiration_date = attributes[:'expiration_date']
  end

  if attributes.key?(:'government_departments')
    self.government_departments = attributes[:'government_departments']
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end
end

Instance Attribute Details

#categoryObject

部門



19
20
21
# File 'lib/gbizinfo/models/certification_info.rb', line 19

def category
  @category
end

#date_of_approvalObject

認定日



22
23
24
# File 'lib/gbizinfo/models/certification_info.rb', line 22

def date_of_approval
  @date_of_approval
end

#enterprise_scaleObject

企業規模



25
26
27
# File 'lib/gbizinfo/models/certification_info.rb', line 25

def enterprise_scale
  @enterprise_scale
end

#expiration_dateObject

有効期限



28
29
30
# File 'lib/gbizinfo/models/certification_info.rb', line 28

def expiration_date
  @expiration_date
end

#government_departmentsObject

府省



31
32
33
# File 'lib/gbizinfo/models/certification_info.rb', line 31

def government_departments
  @government_departments
end

#targetObject

対象



34
35
36
# File 'lib/gbizinfo/models/certification_info.rb', line 34

def target
  @target
end

#titleObject

届出認定等



37
38
39
# File 'lib/gbizinfo/models/certification_info.rb', line 37

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/gbizinfo/models/certification_info.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/gbizinfo/models/certification_info.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/gbizinfo/models/certification_info.rb', line 40

def self.attribute_map
  {
    :'category' => :'category',
    :'date_of_approval' => :'date_of_approval',
    :'enterprise_scale' => :'enterprise_scale',
    :'expiration_date' => :'expiration_date',
    :'government_departments' => :'government_departments',
    :'target' => :'target',
    :'title' => :'title'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/gbizinfo/models/certification_info.rb', line 170

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/gbizinfo/models/certification_info.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/gbizinfo/models/certification_info.rb', line 63

def self.openapi_types
  {
    :'category' => :'String',
    :'date_of_approval' => :'String',
    :'enterprise_scale' => :'String',
    :'expiration_date' => :'String',
    :'government_departments' => :'String',
    :'target' => :'String',
    :'title' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



143
144
145
146
147
148
149
150
151
152
153
# File 'lib/gbizinfo/models/certification_info.rb', line 143

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      category == o.category &&
      date_of_approval == o.date_of_approval &&
      enterprise_scale == o.enterprise_scale &&
      expiration_date == o.expiration_date &&
      government_departments == o.government_departments &&
      target == o.target &&
      title == o.title
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


157
158
159
# File 'lib/gbizinfo/models/certification_info.rb', line 157

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



163
164
165
# File 'lib/gbizinfo/models/certification_info.rb', line 163

def hash
  [category, date_of_approval, enterprise_scale, expiration_date, government_departments, target, title].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



128
129
130
131
132
# File 'lib/gbizinfo/models/certification_info.rb', line 128

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/gbizinfo/models/certification_info.rb', line 192

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



136
137
138
139
# File 'lib/gbizinfo/models/certification_info.rb', line 136

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end