Class: Gbizinfo::HojinInfoResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Gbizinfo::HojinInfoResponse
- Defined in:
- lib/gbizinfo/models/hojin_info_response.rb
Instance Attribute Summary collapse
-
#errors ⇒ Object
エラー情報(エラーがある場合に出力します。).
-
#hojin_infos ⇒ Object
gBizINFOデータ.
-
#id ⇒ Object
リクエストid.
-
#message ⇒ Object
メッセージ.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HojinInfoResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ HojinInfoResponse
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/gbizinfo/models/hojin_info_response.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Gbizinfo::HojinInfoResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Gbizinfo::HojinInfoResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'errors') if (value = attributes[:'errors']).is_a?(Array) self.errors = value end end if attributes.key?(:'hojin_infos') if (value = attributes[:'hojin_infos']).is_a?(Array) self.hojin_infos = value end end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'message') self. = attributes[:'message'] end end |
Instance Attribute Details
#errors ⇒ Object
エラー情報(エラーがある場合に出力します。)
19 20 21 |
# File 'lib/gbizinfo/models/hojin_info_response.rb', line 19 def errors @errors end |
#hojin_infos ⇒ Object
gBizINFOデータ
22 23 24 |
# File 'lib/gbizinfo/models/hojin_info_response.rb', line 22 def hojin_infos @hojin_infos end |
#id ⇒ Object
リクエストid
25 26 27 |
# File 'lib/gbizinfo/models/hojin_info_response.rb', line 25 def id @id end |
#message ⇒ Object
メッセージ
28 29 30 |
# File 'lib/gbizinfo/models/hojin_info_response.rb', line 28 def @message end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/gbizinfo/models/hojin_info_response.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/gbizinfo/models/hojin_info_response.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 |
# File 'lib/gbizinfo/models/hojin_info_response.rb', line 31 def self.attribute_map { :'errors' => :'errors', :'hojin_infos' => :'hojin-infos', :'id' => :'id', :'message' => :'message' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/gbizinfo/models/hojin_info_response.rb', line 144 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 |
# File 'lib/gbizinfo/models/hojin_info_response.rb', line 61 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 |
# File 'lib/gbizinfo/models/hojin_info_response.rb', line 51 def self.openapi_types { :'errors' => :'Array<ApiErrorResponse>', :'hojin_infos' => :'Array<HojinInfo>', :'id' => :'String', :'message' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
120 121 122 123 124 125 126 127 |
# File 'lib/gbizinfo/models/hojin_info_response.rb', line 120 def ==(o) return true if self.equal?(o) self.class == o.class && errors == o.errors && hojin_infos == o.hojin_infos && id == o.id && == o. end |
#eql?(o) ⇒ Boolean
131 132 133 |
# File 'lib/gbizinfo/models/hojin_info_response.rb', line 131 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
137 138 139 |
# File 'lib/gbizinfo/models/hojin_info_response.rb', line 137 def hash [errors, hojin_infos, id, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
105 106 107 108 109 |
# File 'lib/gbizinfo/models/hojin_info_response.rb', line 105 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/gbizinfo/models/hojin_info_response.rb', line 166 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
113 114 115 116 |
# File 'lib/gbizinfo/models/hojin_info_response.rb', line 113 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |