Class: Gbizinfo::SubsidyInfo
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Gbizinfo::SubsidyInfo
- Defined in:
- lib/gbizinfo/models/subsidy_info.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
金額.
-
#date_of_approval ⇒ Object
認定日.
-
#government_departments ⇒ Object
府省.
-
#joint_signatures ⇒ Object
連名.
-
#note ⇒ Object
備考.
-
#subsidy_resource ⇒ Object
補助金財源.
-
#target ⇒ Object
対象.
-
#title ⇒ Object
補助金等.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SubsidyInfo
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SubsidyInfo
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/gbizinfo/models/subsidy_info.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Gbizinfo::SubsidyInfo` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Gbizinfo::SubsidyInfo`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'date_of_approval') self.date_of_approval = attributes[:'date_of_approval'] end if attributes.key?(:'government_departments') self.government_departments = attributes[:'government_departments'] end if attributes.key?(:'joint_signatures') if (value = attributes[:'joint_signatures']).is_a?(Array) self.joint_signatures = value end end if attributes.key?(:'note') self.note = attributes[:'note'] end if attributes.key?(:'subsidy_resource') self.subsidy_resource = attributes[:'subsidy_resource'] end if attributes.key?(:'target') self.target = attributes[:'target'] end if attributes.key?(:'title') self.title = attributes[:'title'] end end |
Instance Attribute Details
#amount ⇒ Object
金額
19 20 21 |
# File 'lib/gbizinfo/models/subsidy_info.rb', line 19 def amount @amount end |
#date_of_approval ⇒ Object
認定日
22 23 24 |
# File 'lib/gbizinfo/models/subsidy_info.rb', line 22 def date_of_approval @date_of_approval end |
#government_departments ⇒ Object
府省
25 26 27 |
# File 'lib/gbizinfo/models/subsidy_info.rb', line 25 def government_departments @government_departments end |
#joint_signatures ⇒ Object
連名
28 29 30 |
# File 'lib/gbizinfo/models/subsidy_info.rb', line 28 def joint_signatures @joint_signatures end |
#note ⇒ Object
備考
31 32 33 |
# File 'lib/gbizinfo/models/subsidy_info.rb', line 31 def note @note end |
#subsidy_resource ⇒ Object
補助金財源
34 35 36 |
# File 'lib/gbizinfo/models/subsidy_info.rb', line 34 def subsidy_resource @subsidy_resource end |
#target ⇒ Object
対象
37 38 39 |
# File 'lib/gbizinfo/models/subsidy_info.rb', line 37 def target @target end |
#title ⇒ Object
補助金等
40 41 42 |
# File 'lib/gbizinfo/models/subsidy_info.rb', line 40 def title @title end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/gbizinfo/models/subsidy_info.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/gbizinfo/models/subsidy_info.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/gbizinfo/models/subsidy_info.rb', line 43 def self.attribute_map { :'amount' => :'amount', :'date_of_approval' => :'date_of_approval', :'government_departments' => :'government_departments', :'joint_signatures' => :'joint_signatures', :'note' => :'note', :'subsidy_resource' => :'subsidy_resource', :'target' => :'target', :'title' => :'title' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/gbizinfo/models/subsidy_info.rb', line 182 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/gbizinfo/models/subsidy_info.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/gbizinfo/models/subsidy_info.rb', line 67 def self.openapi_types { :'amount' => :'String', :'date_of_approval' => :'String', :'government_departments' => :'String', :'joint_signatures' => :'Array<String>', :'note' => :'String', :'subsidy_resource' => :'String', :'target' => :'String', :'title' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/gbizinfo/models/subsidy_info.rb', line 154 def ==(o) return true if self.equal?(o) self.class == o.class && amount == o.amount && date_of_approval == o.date_of_approval && government_departments == o.government_departments && joint_signatures == o.joint_signatures && note == o.note && subsidy_resource == o.subsidy_resource && target == o.target && title == o.title end |
#eql?(o) ⇒ Boolean
169 170 171 |
# File 'lib/gbizinfo/models/subsidy_info.rb', line 169 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
175 176 177 |
# File 'lib/gbizinfo/models/subsidy_info.rb', line 175 def hash [amount, date_of_approval, government_departments, joint_signatures, note, subsidy_resource, target, title].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
139 140 141 142 143 |
# File 'lib/gbizinfo/models/subsidy_info.rb', line 139 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/gbizinfo/models/subsidy_info.rb', line 204 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
147 148 149 150 |
# File 'lib/gbizinfo/models/subsidy_info.rb', line 147 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |